@@ -13,7 +13,7 @@
 # more details.
 #
 # You should have received a copy of the GNU General Public License along with
-# GNU Mailman.  If not, see <http://www.gnu.org/licenses/>.
+# GNU Mailman.  If not, see <https://www.gnu.org/licenses/>.
 
 """Test some additional corner cases for starting/stopping."""
 
@@ -151,15 +151,32 @@ def kill_with_extreme_prejudice(pid_or_pidfile=None):
             os.kill(pid, signal.SIGKILL)
         until = timedelta(seconds=10) + datetime.now()
         while datetime.now() < until:
-            status = os.waitpid(pid, os.WNOHANG)
-            if status == (0, 0):
-                # The child was reaped.
+            try:
+                os.waitpid(pid, os.WNOHANG)
+            except ChildProcessError:
+                # 2016-03-10 maxking: We are seeing ChildProcessError very
+                # often in CI due to the os.waitpid on L155 above. This is
+                # raised when there is no child process left. We are clearly in
+                # the arena of a race condition where the process was killed
+                # somewhere after we checked and before we tried to wait on
+                # it. TOCTTOU problem.
                 return
             time.sleep(0.1)
         else:
             print('WARNING: SIGKILL DID NOT EXIT PROCESS!', file=sys.stderr)
 
 
+@public
+def clean_stale_locks():
+    """Cleanup the master.pid and master.lck file, if they exist."""
+    # If the master process was force-killed during the test suite run, it is
+    # possible that the stale pid file was left. Clean that file up.
+    if os.path.exists(config.PID_FILE):
+        os.unlink(config.PID_FILE)
+    if os.path.exists(config.LOCK_FILE):
+        os.unlink(config.LOCK_FILE)
+
+
 class TestControl(unittest.TestCase):
     layer = ConfigLayer
     maxDiff = None
